@@ -2,7 +2,7 @@
     Estimation of geometry of horizontal tail
 """
 #  This file is part of FAST-OAD : A framework for rapid Overall Aircraft Design
-#  Copyright (C) 2020  ONERA & ISAE-SUPAERO
+#  Copyright (C) 2021 ONERA & ISAE-SUPAERO
 #  FAST is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
 #  the Free Software Foundation, either version 3 of the License, or
@@ -14,14 +14,19 @@
 #  You should have received a copy of the GNU General Public License
 #  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+import fastoad.api as oad
 import openmdao.api as om
-
 from fastoad.models.geometry.geom_components.ht.components import ComputeHTChord
 from fastoad.models.geometry.geom_components.ht.components import ComputeHTClalpha
 from fastoad.models.geometry.geom_components.ht.components import ComputeHTMAC
 from fastoad.models.geometry.geom_components.ht.components import ComputeHTSweep
 
+from ...constants import SERVICE_HORIZONTAL_TAIL_GEOMETRY
 
+
+@oad.RegisterSubmodel(
+    SERVICE_HORIZONTAL_TAIL_GEOMETRY, "fastoad.submodel.geometry.horizontal_tail.legacy"
+)
 class ComputeHorizontalTailGeometry(om.Group):
     """ Horizontal tail geometry estimation """
 
