@@ -94,6 +94,8 @@ class OMRubberEngineWrapper(IOMPropulsionWrapper):
             desc="As it is a delta, unit is K or °C, but is not "
             "specified to avoid OpenMDAO making unwanted conversion",
         )
+        component.add_input("tuning:propulsion:rubber_engine:SFC:k_sl", 1.0)
+        component.add_input("tuning:propulsion:rubber_engine:SFC:k_cr", 1.0)
 
     @staticmethod
     def get_model(inputs) -> IPropulsion:
@@ -116,6 +118,8 @@ class OMRubberEngineWrapper(IOMPropulsionWrapper):
             "delta_t4_climb": inputs["data:propulsion:rubber_engine:delta_t4_climb"],
             "delta_t4_cruise": inputs["data:propulsion:rubber_engine:delta_t4_cruise"],
             "mto_thrust": inputs["data:propulsion:MTO_thrust"],
+            "k_sfc_sl": inputs["tuning:propulsion:rubber_engine:SFC:k_sl"],
+            "k_sfc_cr": inputs["tuning:propulsion:rubber_engine:SFC:k_cr"],
         }
 
         return RubberEngine(**engine_params)
